@@ -1,7 +1,7 @@
 CombineExact <-function (Xmat, alternative="less")
 {
     m <- nrow(Xmat)
-    pvecless <- HWExactMat(Xmat,pvaluetype="midp",alternative="less",verbose=FALSE)$pvalvec
+    pvecless <- HWExactStats(Xmat,plinkcode=FALSE,pvaluetype="midp",alternative="less")
 #    pvecgrea <- HWExactMat(Xmat,pvaluetype="midp",alternative="greater")$pvalvec
 #    pvecgrea <- 1 - pvecless
     mipless <- mipvalue(pvecless)
